@@ -4,7 +4,7 @@ from typing import *
 from pathlib import Path
 
 from . import CorrectnessResult
-from .. import Test
+from .. import Test, Result
 from ...task import Error
 from ....library.process import Runtime, Interactive, InteractiveStreamTimeoutExpired, Interaction
 from ....library.configurable import none, not_none, Configurable
@@ -183,22 +183,22 @@ class CompareBytesOutputTest(OutputTest, Configurable):
         return CorrectnessResult(passing=passing, error=error)
 
 
-def test_runtime_succeeded(runtime: Runtime) -> CorrectnessResult:
+def test_runtime_succeeded(runtime: Runtime, result_type):
     """See if the runtime raised exceptions or returned status code."""
 
     if runtime.raised_exception:
         error = Error(description=runtime.exception.description)
-        raise CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
+        raise result_type(passing=False, runtime=runtime.dump(), error=error)
     if runtime.timed_out:
         error = Error(
             description="timed out",
             suggestion=f"expected maximum elapsed time of {runtime.timeout} seconds")
-        raise CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
+        raise result_type(passing=False, runtime=runtime.dump(), error=error)
     if runtime.code != 0:
         error = Error(
             description=f"received status code {runtime.code}",
             suggestion="expected status code of zero")
-        return CorrectnessResult(passing=False, runtime=runtime.dump(), error=error)
+        raise result_type(passing=False, runtime=runtime.dump(), error=error)
 
 
 class ExecutableMixin(OutputTest, Configurable):
