@@ -16,6 +16,8 @@ def sum_weights(tasks: Iterable[dict]) -> float:
 class ProblemSummary:
     """A summary of the results from a problem's cases."""
 
+    problem_short: str
+
     # Main tests
     tests_total: int = 0
     tests_correct: List[dict] = field(default_factory=list)
@@ -33,6 +35,15 @@ class ProblemSummary:
 
         numerator = sum_weights(self.tests_correct)
         denominator = numerator + sum_weights(self.tests_incorrect)
+        if self.problem_short == "coloring":
+            return f"{numerator}/{denominator} = {numerator * 4}/{denominator * 4}"
+        if self.problem_short == "bst-avl":
+            return f"{numerator}/{denominator} = {round(numerator * 55/74, 3)}/{55}"
+        if self.problem_short == "grocery":
+            return f"{numerator}/{denominator} = {round(numerator * 15/20, 3)}/{15}"
+        if self.problem_short == "trie":
+            return f"{numerator}/{denominator} = {round(numerator * 15/28, 3)}/{15}"
+
         return f"{numerator}/{denominator}"
 
     @property
@@ -58,7 +69,7 @@ def summarize(grading_schema: dict, report: dict) -> ReportSummary:
 
     summary = ReportSummary()
     for problem_short, problem in grading_schema["problems"].items():
-        problem_summary = summary.problems[problem_short] = ProblemSummary()
+        problem_summary = summary.problems[problem_short] = ProblemSummary(problem_short)
         for task_name, task in problem["tasks"].items():
             result = report[problem_short][task_name]
 
